@@ -1,9 +1,9 @@
 """This module allows National Instruments TDM/TDX files to be accessed like
 NumPy structured arrays.
 
-It can be installed in the standard way::
+To install the newest version use::
 
-    python setup.py install
+    pip install tdm-loader
 
 Sample usage::
 
@@ -24,7 +24,6 @@ Search for a column name.  A list of all column names that contain
     data_file.channel_search(search_term)
 """
 import os
-import io
 import zipfile
 import re
 
